#!/bin/bash

# Recursively add files to an MPV playlist and open the file at a random seek point.
# Execute this script from within a directory you want to recursively shuffle through.
# Generate a random number between 10 and 90. Use this for the seek percentage when the video opens. (Intended to ignore intros and credits)

MINSEEK=10;
MAXSEEK=90;
RANGE=$(($MAXSEEK-$MINSEEK+1));
RESULT=$RANDOM;
let "RESULT %= $RANGE";
RESULT=$(($RESULT+$MINSEEK));
echo $RESULT;

# Open 3 MPV instances spanned across 3 displays with IPC sockets you can send commands into.
# To execute more or less MPV instances for different display configurations, adjust these lines as needed.
mpv --volume=35 --fs --fs-screen=0 --shuffle --input-ipc-server=/tmp/mpv0 --start=$RESULT% ** &
mpv --volume=35 --fs --fs-screen=1 --shuffle --input-ipc-server=/tmp/mpv1 --start=$RESULT% ** &
mpv --volume=35 --fs --fs-screen=2 --shuffle --input-ipc-server=/tmp/mpv2 --start=$RESULT% ** &

# Send input to IPC sockets to go to the next playlist item and seek to a random point using $RESULT. Loop endlessly. Hit Q in MPV to stop a player instance.
# Increase or decrease sleep times to adjust preview lengths.
while true
do
                sleep 60

                # Randomise seek time each round
                RANGE=$(($MAXSEEK-$MINSEEK+1));
                RESULT=$RANDOM;
                let "RESULT %= $RANGE";
                RESULT=$(($RESULT+$MINSEEK));

                # Adjust these lines as needed when using a display configuration other than the default of 3.
                
                # Display 1 (--fs-screen=0)
                echo 'playlist-next' | socat - /tmp/mpv0; sleep 0.4; echo "no-osd seek $RESULT absolute-percent" | socat - /tmp/mpv0 &

                sleep 5

                # Display 2 (--fs-screen=1)
                echo 'playlist-next' | socat - /tmp/mpv1; sleep 0.4; echo "no-osd seek $RESULT absolute-percent" | socat - /tmp/mpv1 &

                sleep 5
                
                # Display 3 (--fs-screen=3)
                echo 'playlist-next' | socat - /tmp/mpv2; sleep 0.4; echo "no-osd seek $RESULT absolute-percent" | socat - /tmp/mpv2 &
done
